using System;
using System.Web;
using System.Reflection;

public class ControllerHttpHandler : IHttpHandler
{
	public void ProcessRequest(HttpContext context)
	{
		string[] parts = context.Request.Path.Split('/');
		if (parts.Length < 4) {
			context.Response.Write("No controller & member specified");
			return;
		}

		string controllerName = parts[2];
		string methodName = parts[3];

		Type potentialController = Type.GetType(controllerName);
		if (potentialController != null && potentialController.IsClass && potentialController.IsSubclassOf(typeof(Controller))) {
			MethodInfo potentialMethod = potentialController.GetMethod(methodName);
			if (potentialMethod != null) {
				Controller controller = (Controller) Activator.CreateInstance(potentialController, context);
				potentialMethod.Invoke(controller, null);
			}
			else
				context.Response.Write(String.Format("Method '{0}' not found on controller '{1}'", methodName, controllerName));
		}
		else
			context.Response.Write(String.Format("Controller '{0}' not found", controllerName));
	}

	public bool IsReusable
	{
		get { return false; }
	}
}